@@ -102,6 +102,13 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
                             "Please do not use disposable email accounts.</note>",
                             DrKonqi::crashedApplication()->bugReportAddress(),
                             KDE_BUGZILLA_CREATE_ACCOUNT_URL));
+
+    // Don't advertise saving credentials when we can't save them.
+    // https://bugs.kde.org/show_bug.cgi?id=363570
+    if (!KWallet::Wallet::isEnabled()) {
+        ui.m_savePasswordCheckBox->setVisible(false);
+        ui.m_savePasswordCheckBox->setCheckState(Qt::Unchecked);
+    }
 }
 
 bool BugzillaLoginPage::isComplete()
@@ -228,6 +235,10 @@ void BugzillaLoginPage::walletLogin()
             }
 
         }
+
+        if (canLogin()) {
+            loginClicked();
+        }
     }
 }
 
@@ -297,50 +308,62 @@ bool BugzillaLoginPage::canSetCookies()
 
 void BugzillaLoginPage::loginClicked()
 {
-    if (!(ui.m_userEdit->text().isEmpty() || ui.m_passwordEdit->password().isEmpty())) {
+    if (!canLogin()) {
+        loginFinished(false);
+        return;
+    }
 
-        if ((bugzillaManager()->securityMethod() == BugzillaManager::UseCookies)
+    if ((bugzillaManager()->securityMethod() == BugzillaManager::UseCookies)
             && (!canSetCookies())) {
-            return;
+        return;
+    }
+
+    updateWidget(false);
+
+    if (ui.m_savePasswordCheckBox->checkState()==Qt::Checked) { //Wants to save data
+        if (!m_wallet) {
+            openWallet();
         }
+        //Got wallet open ?
+        if (m_wallet) {
+            m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
 
-        updateWidget(false);
-
-        if (ui.m_savePasswordCheckBox->checkState()==Qt::Checked) { //Wants to save data
+            QMap<QString, QString> values;
+            values.insert(QLatin1String(kWalletEntryUsername), ui.m_userEdit->text());
+            values.insert(QLatin1String(kWalletEntryPassword), ui.m_passwordEdit->password());
+            m_wallet->writeMap(QLatin1String(kWalletEntryName), values);
+        }
+    } else { //User doesn't want to save or wants to remove.
+        if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {
             if (!m_wallet) {
                 openWallet();
             }
             //Got wallet open ?
             if (m_wallet) {
                 m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
-
-                QMap<QString, QString> values;
-                values.insert(QLatin1String(kWalletEntryUsername), ui.m_userEdit->text());
-                values.insert(QLatin1String(kWalletEntryPassword), ui.m_passwordEdit->password());
-                m_wallet->writeMap(QLatin1String(kWalletEntryName), values);
-            }
-
-        } else { //User doesn't want to save or wants to remove.
-            if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {
-                if (!m_wallet) {
-                    openWallet();
-                }
-                //Got wallet open ?
-                if (m_wallet) {
-                    m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
-                    m_wallet->removeEntry(QLatin1String(kWalletEntryName));
-                }
+                m_wallet->removeEntry(QLatin1String(kWalletEntryName));
             }
         }
-
-        ui.m_statusWidget->setBusy(i18nc("@info:status '1' is a url, '2' the username",
-                                      "Performing login at %1 as %2...",
-                                      QLatin1String(KDE_BUGZILLA_SHORT_URL), ui.m_userEdit->text()));
-
-        bugzillaManager()->tryLogin(ui.m_userEdit->text(), ui.m_passwordEdit->password());
-    } else {
-        loginFinished(false);
     }
+
+    login();
+}
+
+bool BugzillaLoginPage::canLogin() const
+{
+    return (!(ui.m_userEdit->text().isEmpty() || ui.m_passwordEdit->password().isEmpty()));
+}
+
+void BugzillaLoginPage::login()
+{
+    Q_ASSERT(canLogin());
+
+    ui.m_statusWidget->setBusy(i18nc("@info:status '1' is a url, '2' the username",
+                                     "Performing login at %1 as %2...",
+                                     QLatin1String(KDE_BUGZILLA_SHORT_URL),
+                                     ui.m_userEdit->text()));
+
+    bugzillaManager()->tryLogin(ui.m_userEdit->text(), ui.m_passwordEdit->password());
 }
 
 void BugzillaLoginPage::updateWidget(bool enabled)
@@ -832,9 +855,6 @@ UnhandledErrorDialog::UnhandledErrorDialog(QWidget * parent, const QString & err
                               "to submit a bug against DrKonqi.").arg(error));
     htmlView->setHtml(extendedMessage);
 
-    setMinimumSize(QSize(550, 350));
-    resize(minimumSize());
-
     show();
 }
 
